from abaqusGui import *
import i18n

class SketchFmXYForm(AFXForm):

    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def __init__(self, owner):
        
        AFXForm.__init__(self, owner)
        
        self.cmd = AFXGuiCommand(mode=self, method= 'SketchFmXY', objectName='sketchFmXY')
        self.modelKw = AFXObjectKeyword(self.cmd, 'model', TRUE, 'model')
        self.dataKw = AFXTableKeyword(self.cmd, 'data', TRUE)
        self.flagKw = AFXIntKeyword(self.cmd, 'flag', TRUE, 2)
            

    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def getFirstDialog(self):
        
        db=SketchFmXYDB(self)
        return db
        

    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def getCommandString(self):
    
        from kernelAccess import session
        modelName = session.sessionState[session.currentViewportName]['modelName']
        cmds  = "model = mdb.models['%s']\n" % modelName
        cmds += AFXForm.getCommandString(self)
        return cmds
        
        
class SketchFmXYDB(AFXDataDialog):
    
    
    
    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    def __init__(self, form):
    
         AFXDataDialog.__init__(self, form, i18n.tr('Enter XY Data'),
            self.OK|self.APPLY|self.CANCEL, DIALOG_ACTIONS_SEPARATOR)

         gb = FXGroupBox(self, i18n.tr('Drawing Object'), FRAME_GROOVE|LAYOUT_FILL_X)
         hf = FXHorizontalFrame(gb, 0, 0,0,0,0, 0,0,0,0)
         FXRadioButton(hf, i18n.tr('Point'), form.flagKw, 1)
         FXRadioButton(hf, i18n.tr('Line'), form.flagKw, 2)
         
         gb = FXGroupBox(self, i18n.tr('Enter XY'), FRAME_GROOVE|LAYOUT_FILL_X)
         hf = FXHorizontalFrame(gb, 0, 0,0,0,0, 0,0,0,0)
         table = AFXTable(hf, 21, 3, 10001, 3, form.dataKw,0,AFXTABLE_EDITABLE)
         table.setLeadingColumns(1)
         table.setLeadingRows(1)
         table.setLeadingRowLabels('X\tY')
         table.showHorizontalGrid(TRUE)
         table.showVerticalGrid(TRUE)      
         table.setColumnWidth(0, 30)
         table.setColumnJustify(-1, AFXTable.CENTER) 
         table.setPopupOptions( 
                 AFXTable.POPUP_CUT|AFXTable.POPUP_COPY \
                 |AFXTable.POPUP_PASTE \
                 |AFXTable.POPUP_INSERT_ROW \
                 |AFXTable.POPUP_DELETE_ROW \
                 |AFXTable.POPUP_CLEAR_CONTENTS \
                 |AFXTable.POPUP_READ_FROM_FILE
         )

         

#---- Main

toolset = getAFXApp().getAFXMainWindow().getPluginToolset()

toolset.registerGuiMenuButton(
    object=SketchFmXYForm(toolset), buttonText=i18n.tr('ABAQUS Japan|Sketch|Enter XY Data...'),
    kernelInitString='import sketchFmXY',
    version='1.0', author='ABAQUS Japan',
    description=i18n.tr('This plug-in allows users to enter the x-y coordinate pair into the table to create the points or lines in the sketch and save them into the sketch named "fromXY". The table has also reading the external function.\n\nIf you would like to use Japanese menu, add the contents (convert to UTF8) of the dictionary file (xxx_Dict.txt) installed with this plug-in, to the end of the file, "(abaqus_dir)\\6.6-x\\cae\\Configuration\\Xresources\\ja_JP\\ja_JP_PyDict.py".')
)
# Register a GUI plug-in in a toolbox.
#
